@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: common.h,v 1.23 2006/05/11 00:29:02 evertonm Exp $ */
+/* $Id: common.h,v 1.24 2006/05/12 19:06:47 evertonm Exp $ */
 
 #ifndef NEPIM_COMMON_H
 #define NEPIM_COMMON_H
@@ -81,4 +81,9 @@ void udp_check_packet_data(int sd, nepim_udp_hdr_t *hdr,
                            unsigned char *packet_buf, unsigned header_len,
                            unsigned packet_size);
 
+struct sockaddr *nepim_addrlist_findfirst(int socktype, int proto,
+					  const char *list,
+					  struct sockaddr *addr,
+					  int *addr_len);
+
 #endif /* NEPIM_COMMON_H */
