@@ -21,7 +21,7 @@ MA 02110-1301 USA
 /*
   nepim - network pipemeter
 
-  $Id: main.c,v 1.51 2006/05/12 19:06:47 evertonm Exp $
+  $Id: main.c,v 1.52 2006/05/16 12:28:04 evertonm Exp $
  */
 
 #include <stdlib.h>
@@ -119,6 +119,8 @@ static void usage(FILE *out, const char *prog_name)
           "  -n pipes       number of parallel pipes (defaults to %d)\n"
           "  -r bit-rate    upper bit rate limit (defaults to %s bps)\n"
           "  -R pkt-rate    upper packet rate limit (defaults to %s pps)\n"
+	  "  -D send-delay  delay between sends (defaults to %ld ms)\n"
+	  "                 only meaningful when specified before -r or -R\n"
           "  -i interval    statistics report interval (defaults to %d seconds)\n"
           "  -a age         test duration (defaults to %d seconds)\n"
           "  -S seed        starting seed (in hex) (defaults to random)\n"
@@ -167,6 +169,7 @@ static void usage(FILE *out, const char *prog_name)
           nepim_global.pipes,
           bit_rate,
           pkt_rate,
+          nepim_global.write_delay,
           nepim_global.stat_interval,
           nepim_global.test_duration,
           nepim_global.pause_duration,
@@ -227,6 +230,17 @@ int main(int argc, const char *argv[])
   for (i = 1; i < argc; ++i) {
     const char *arg = argv[i];
 
+    if (!strcmp(arg, "-D")) {
+      ++i;
+      if (i >= argc) {
+        fprintf(stderr, "%s: missing send-delay\n",
+                nepim_global.prog_name);
+        exit(1);
+      }
+      nepim_global.write_delay = atoi(argv[i]);
+      continue;
+    }
+
     if (!strcmp(arg, "-o")) {
       int j = i + 1;
       
@@ -552,9 +566,9 @@ int main(int argc, const char *argv[])
       if (bytes < 1) {
         long long min_bps = nepim_min_bps(nepim_global.write_delay);
         fprintf(stderr,
-                "%s: bit-rate=%lld (bytes=%d) lower than minimum=%lld\n",
+                "%s: bit-rate=%lld bps (bytes=%d) lower than minimum=%lld bps (for send-delay=%ld ms)\n",
                 nepim_global.prog_name,
-                nepim_global.bit_rate, bytes, min_bps);
+                nepim_global.bit_rate, bytes, min_bps, nepim_global.write_delay);
         exit(1);
       }
       assert(nepim_global.bit_rate >= nepim_min_bps(nepim_global.write_delay));
@@ -575,9 +589,9 @@ int main(int argc, const char *argv[])
       if (pkts < 1) {
         int min_pps = nepim_min_pps(nepim_global.write_delay);
         fprintf(stderr,
-                "%s: pkt-rate=%d (pkts=%d) lower than minimum=%d\n",
+                "%s: pkt-rate=%d pps (pkts=%d) lower than minimum=%d pps (for send-delay=%ld ms)\n",
                 nepim_global.prog_name, 
-                nepim_global.pkt_rate, pkts, min_pps);
+                nepim_global.pkt_rate, pkts, min_pps, nepim_global.write_delay);
         exit(1);
       }
       assert(nepim_global.pkt_rate >= nepim_min_pps(nepim_global.write_delay));
