@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: udp_server.c,v 1.91 2006/05/11 12:23:35 evertonm Exp $ */
+/* $Id: udp_server.c,v 1.92 2006/05/12 19:06:47 evertonm Exp $ */
 
 
 #include <stdio.h>
@@ -1053,22 +1053,18 @@ int nepim_udp_listener(const char *hostname, const char *portname,
   }
 
   for (ai = ai_res; ai; ai = ai->ai_next) {
+    char addr_str[500];
     int sd;
 
-#if 0
-    fprintf(stderr, 
-	    "UDP listener: host=%s,%s(%d) len=%d family=%d type=%d proto=%d\n",
-	    hostname, portname, nepim_sock_get_port(ai->ai_addr),
-	    ai->ai_addrlen, ai->ai_family, 
-	    ai->ai_socktype, ai->ai_protocol);
-#endif
-
     if (nepim_global.no_inet6 && (ai->ai_family == PF_INET6))
       continue;
 
     if (nepim_global.no_inet4 && (ai->ai_family == PF_INET))
       continue;
 
+    nepim_sock_dump_addr(addr_str, sizeof addr_str,
+			 ai->ai_addr, ai->ai_addrlen);
+
     sd = nepim_create_socket(ai->ai_addr, ai->ai_addrlen,
 			     ai->ai_family, ai->ai_socktype, 
 			     ai->ai_protocol,
@@ -1081,8 +1077,9 @@ int nepim_udp_listener(const char *hostname, const char *portname,
 			     nepim_global.tos);
     if (sd < 0) {
       fprintf(stderr, 
-	      "nepim_udp_listener: UDP listener socket failed for %s,%s(%d): %d\n",
-	      hostname, portname, nepim_sock_get_port(ai->ai_addr), sd);
+              "%s %s: UDP listener socket failed for %s,%d: %d\n",
+              __FILE__, __PRETTY_FUNCTION__,
+	      addr_str, nepim_sock_get_port(ai->ai_addr), sd);
       break;
     }
 
@@ -1095,8 +1092,8 @@ int nepim_udp_listener(const char *hostname, const char *portname,
     ++udp_listeners;
 
     fprintf(stderr, 
-	    "%d: UDP socket listening on %s,%s(%d)\n",
-	    sd, hostname, portname, nepim_sock_get_port(ai->ai_addr));
+	    "%d: UDP socket listening on %s,%d\n",
+	    sd, addr_str, nepim_sock_get_port(ai->ai_addr));
 
     nepim_sock_show_opt(stderr, sd);
   }
