@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: usock.h,v 1.6 2005/11/04 09:56:15 evertonm Exp $ */
+/* $Id: usock.h,v 1.7 2006/03/29 21:23:14 evertonm Exp $ */
 
 #ifndef NEPIM_USOCK_H
 #define NEPIM_USOCK_H
@@ -60,9 +60,9 @@ int nepim_usock_reader_del(nepim_usock_set_t *set, int index);
 
 void nepim_usock_write_error(nepim_usock_set_t *set, int index,
 			     int local_slot, int remote_slot,
-			     int err_no);
+			     int err_no, int verbose);
 void nepim_usock_read_error(nepim_usock_set_t *set, int index,
-			    int err_no);
+			    int err_no, int verbose);
 void nepim_usock_write_good(nepim_usock_set_t *set, int index);
 void nepim_usock_read_good(nepim_usock_set_t *set, int index);
 
